erddapList: A list of edinfo objects from ERDDAP data sources

erddapListR Documentation

A list of edinfo objects from ERDDAP data sources

Description

A list of edinfo objects, mostly used internally for functions. These objects represent different environmental data sources from ERDDAP servers and are used to download environmental data.

Usage

erddapList

Format

A list with objects of class edinfo

Southwest Fisheries Science Center / NMFS / NOAA


PAMmisc documentation built on Sept. 22, 2026, 1:08 a.m.