powered by
This function gets the list of environmental datasets provided as a recommended starting point for various measures
getEdinfo()
a list of edinfo list objects
Taiki Sakai [email protected]
ediList <- getEdinfo() ediList[[1]] ediList[['jplMURSST41']]
Run the code above in your browser using DataLab